# Entwicklung einer Neo-Tastatur

Es gibt schon länger Überlegungen, eine eigene Tastatur zu entwerfen, die ideal für Neo geeignet ist.

Insgesamt entstanden die Ideen auf dieser Seite, bevor das [Truly Ergonomic Keyboard](Truly.md) verfügbar war. Inzwischen haben sich einige Neolinge diese Tastatur gekauft und das Interesse an einer eigenen Neo-Hardware ist gesunken.

## Grund für eigene Neo-Hardware

Es gibt viele unterschiedliche Tastaturen zu kaufen, allerdings gibt es keine, die alle Vorteile von Neo ausnutzt und zugleich ergonomisch ist.
Entweder fehlen Tasten oder sind schlecht erreichbar, oder es sind durch Neo unnötig gewordene Tasten vorhanden.
Zudem sind Tastaturen, die wenigstens einen Teil der Anforderungen erfüllen, preislich uninteressant.

## Anforderungen

Die Tastatur soll vor allem ergonomisch sinnvoll sein.

Der Wissensstand bis 2008 ist zusammengefasst in „Ergonomische Anforderungen an Eingabemittel für Geräte der Informationstechnik (BGIA-Report 3/2008)“.

Auf der Internetseite kann er heruntergeladen werden: [BGIA-Report 3/2008](http://www.dguv.de/ifa/Publikationen/Reports-Download/BGIA-Reports-2007-bis-2008/BGIA-Report-3-2008/index.jsp)

### Anzahl der Tasten

Die neue Tastatur muss natürlich den vollen Funktionsumfang der bisherigen Standardtastatur mit 105 Tasten bieten.
Es werden aber nicht alle 105 Tasten benötigt, da Neo einiges im Hauptfeld wiederholt.

### Tastaturtyp

Bei der Standardtastatur sind die Tastenreihen gegeneinander verschoben.
Der Grund dafür ist bei der mechanischen Schreibmaschine zu suchen, bei der die Tastenhebel der vier Reihen nebeneinander Platz finden mussten.
Dass dieser unreflektiert kopierte Unsinn beseitigt werden muss, steht außer Frage,
die einfachste Folgerung ist eine Matrixanordnung der Tasten.
Jakob H. schrieb jedoch am 9.9.2010 auf der ML, dass ihm die Matrixanordnung erstmal schwer gefallen sei, es fordert wohl reichlich Umstellung.

Zusätzlich könnte man noch – wie z. B. beim Truly Ergonomic Keyboard – die Spalten bogenförmig verschieben, um die unterschiedlichen Längen der Finger zu berücksichtigen.

Außerdem sollten die Daumen mehr einbezogen werden (von Zehnfingerschreiben kann mit der Standardtastatur keine Rede sein).
So könnte ein Teil der Modifiertasten von den kleinen Fingern auf die Daumen verlagert werden.

Außerdem sollte eine in irgendeiner Form geteilte Tastatur vorausgesetzt werden.
Nur so brauchen die Handgeleke beim Tippen nicht abgewinkelt zu werden.
Über die genaue Umsetzung kann dabei noch diskutiert werden: Delta-Form, flexible Anordnung der Hälften zueinander, vielleicht auch vertikal positionierbar …?

Weitere Inspirationen lassen sich auf der [Übersichtsseite](index.md#ergonomische-tastaturen) holen.


### Tasten/Spalten pro Hand, Mittelspalte

Bei Standardtastaturen hat die rechte Hand zwei Spalten mehr zu bedienen als die linke (beide Zeigefinger bedienen zwei Spalten, Mittel- und Ringfinger je eine, aber der linke kleine Finger hat eine Spalte Buchstaben plus Modifier, während der rechte kleine Finger 2½ Spalten Buchstaben plus Modifier erreichen muss.
Dieses Ungleichgewicht sollte ausgeglichen werden, nur wohin mit den Kleinfingertasten?

Die Typematrix verwendet eine mittlere Spalte, die von beiden Seiten aus verwendet werden soll/kann. Jakob H. konnte auch dies testen, und empfand es als schmerzhaft, die Zeigefinger so weit zur Mitte abspreizen zu müssen.
Außerdem ist eine Mittelspalte nicht mit einer beweglich geteilten Tastatur vereinbar.


### Schnittstelle

Die Standardschnittstelle für Tastaturen ist mittlerweile USB.
Viele Rechner haben gar keine PS/2-Schnittstelle mehr.
PS/2 sollte aber aus Gründen der Abwärtskompatibilität über einen einfachen Adapter auch möglich sein (so wie dies auch bei aktuellen Standardtastaturen der Fall ist).
Die Tastatur sollte sich gegenüber dem PC wie eine Standardtastatur verhalten und dadurch keinen besonderen Treiber auf PC-Seite benötigen.

### Elektronik

Wenn der physische Navigationsblock entfällt, so muss die Tastatur bei Betätigung der Navigationstasten auf Ebene 4 die entsprechenden Keycodes senden, da ansonsten (nicht nur) das BIOS nicht mehr bedient werden kann.
Standard-Encoder werden dies nicht bewerkstelligen können, und erfordern deshalb zumindest zusätzliche Mikrotaster, die die Grundfunktionalität sicherstellen.

Will man nicht auf vorgefertigte Tastatur-Encoder zurückgreifen, so ist ein Mikrokontroller nötig, der dann auch mit einer Firmware ausgestattet werden muss.
Diese Firmware muss die Tastendrücke auswerten, und die entsprechenden Scancodes dann per USB oder PS/2 an den PC senden.

Mit normalen Tastaturen gibt es immer wieder [Probleme mit Rollover](../Probleme/Hardwareprobleme.md).
Dies ist durch N-Key-Rollover zu verhindern.
Bei USB-Tastaturen können zwar maximal 6 gleichzeitig gedrückte Tasten übermittelt werden,
dies hat aber nichts mit der Tastaturmatrix zu tun und sollte für Neo ausreichend sein. 
Höchstens Computerspieler sollen diese Beschränkung schon wahrgenommen haben.


### Weitere Kriterien

 * Tastatur in der Mitte höher als an den Seiten (Dach-Form), damit die Hände ihrer Neutralhaltung näherkommen
 * möglichst geräuschlos
 * nicht zu hoher Hub
 * ergnomische Betätigungscharakteristik (erfordert Mindesthubhöhe / idealerweise mechanische Tastenmodule)
 * Rastermaß des Tastenmittenabstandes ca. 17,5 mm bis 18,2 mm (statt 19,05 mm)
 * die dem Benutzer zugewandte Seite (Leertaste) soll etwa gleich hoch liegen wie die abgewandte Seite (Funktionstastenzeile), d. h. keine Tastaturneigung
 * die Gesamthöhe der Tastatur soll gering sein (unter 20 mm)
 * keine Handballenauflage bzw. ca. 12 mm Höhendifferenz zwischen Arbeitsplatte und Tastatur
 * preislich attraktiv

## Ideen, Vorschläge

### Anzahl der Tasten

#### Vorschlag Nora

Wir müssen 30 Buchstaben, 10 Zahlen, 3× Tote Tasten unterbringen,
das sind 43 „normale“ Tasten:

```
a b c d e f g h i j k l m n o p q r s t u v w x y z ä ö ü ß
1 2 3 4 5 6 7 8 9 0
T1 T2 T3
```

Dazu je 2× Shift, M3 und M4; je 1× oder 2× Strg, Alt, Fenster, Menü, Leertaste 
und evt. Backspace, Tab, Return, Esc, Compose, Entf [Strg+Alt+Entf…]
sowie Multimediatasten wie Redo, Power, Sleep und Wake.
Noch weiter in den „Randbereich“ vordringend, kämen noch die Funktionstasten (F1–F12) dazu, die jedoch vermutlich einfach als Reihe obendrüber bleiben.
Außerdem evt. noch der ganze Ziffern/Navigationsblock, der jedoch auf Ebene 4 gut verfügbar ist, und somit auf einer speziellen Neo-Tastatur nicht nötig sein sollte?
Das sind 12–∞ „Spezialtasten“:

```
2 × Shift, M3, M4
1 od. 2 × Strg, Alt, Fenster, Menü, Leertaste
evt. Back, Tab, Ret, Esc, Compose, Entf, Fn
(Redo, Power, Sleep, Wake)
```

Einerseits sind zusätzliche Tasten nicht weiter störend, sie müssen ja nicht genutzt werden.
Wichtig ist nur, dass alle benötigten Tasten gut erreichbar sind.

Andererseits ermöglicht eine schmale Tastatur einen besseren Wechsel zw. Tastatur und Maus und benötigt weniger Platz auf dem Schreibtisch.


#### Vorschlag Miche

Der andere Ansatz ist, vom  Standard-105-Tasten-Modell auszugehen, und alles abzuziehen, das überflüssig ist.

```
 105 Standard
− 17 Ziffernblock
− 14 Navigationsblock
− 13 Funktionstasten
+  2 Fn-Tasten
=====================
  63 Tasten
```

Der Ziffernblock soll separat aufstellbar sein, wird teilweise durch die 4. Ebene von Neo ersetzt und ist für die, die ihn unbedingt benötigen, als separates Teil im Handel erhältlich.
Der durch die 4. Ebene überflüssige originale Navigationsblock verleitet zum Verlassen der Grundstellung.
Die Tasten Fenster_R, Menü, Druck, Rollen und Pause, sowie F5 – F12 werden – ähnlich wie dies teilweise bei Notebooks geschieht – auf eine Fn-Ebene ausgelagert, die mindestens eine Fn-Taste erfordert.

Zu dieser Überlegung gibt es eine [rudimentäre graphische Darstellung](http://miche.host4free.de/vgl.png).

#### Vorschlag Joschua
Die Tastatur ist …

  * komplett in zwei Hälften geteilt, welche, wie bei der Kinesis Freestyle, mit einem Kabel verbunden sind.
    * Durch die Teilung kann man die Tastatur an die jeweiligen Winkel der Hände zueinander anpassen.
    * Tasten in der Mitte würden dies verhindern, weshalb man davon absehen sollte.
    * Weiterhin sollten beide Hälften eine Handballen-Auflage besitzen (zur Entspannung der Hände).
  * an der Vorderseite (wo die Leertaste ist) höher (ähnlich dem Micosoft Natural Ergonomic Desktop 7000).
  * an den Innenseiten der beiden Teile wesentlich höher (evtl. verstellbar), um die Hände in die Neutralhaltung zu bringen.

Die Tastatur sollte …

  * auf unnötige, schwer zu erreichbare oder selten genutzte Tasten (wie den Num-Block) verzichten.
  * auf beiden Seiten gleich viele Tasten haben.
  * keine redundanten Zeichen / Tasten haben (mit Ausnahme der Modifier).
    * Wie bei der Plum-Tastatur sollte die Leertaste in Enter (links) und Leertaste (rechts) aufgeteilt werden.
  * sollte auf der Ebene 4 alle mathematischen Zeichen für Berechnungen enthalten (z.B: Wurzel-Zeichen), da Neo dort den alten Numblock ermöglicht.
    * Wenn die Leertaste (welche dann 0 ist) genau so groß wie 1, 2 und 3 zusammen sind, wäre das optimal um Zahlen schnell und fehlerfrei einzugeben.
  * Die Null auf der Haupt-Ebene sollte aus logischen Gründen vor die Eins gestellt werden.
  * einfache und klare Bezeichnungen bzw. Symbole für die Ebenen nutzen (z.B. 1+2-3 für die "Zahlen"-Ebene 4).

Die Tastatur könnte …

  * einen integrierten Trackball haben. Diese sind ergonomischer, robuster und benötigen keinen "Spielraum" oder Mauspads.

Weiterhin wäre es sinnvoll das Layout um eine siebte Ebene zu erweitern. Auf dieser "Funktions"-Ebene (mit einer blauen Fn-Taste ausgelöst) können verschiedene [XF86-Tasten](http://wiki.linuxquestions.org/wiki/XF86_keyboard_symbols) (sollten ebenfalls blau markiert sein) ausgeführt werden. Zusätzlich sollten hier auch die alten F-Tasten (F1 - F12) liegen.

### Tastenanordnung

#### Nora1

Eine Möglichkeit wäre, beiden kleinen Fingern je zwei Spalten zu geben, dafür M4 zum Daumen zu legen, die Leertaste muss dann natürlich schmal genug sein, damit M4 gut erreichbar bleibt:

```
┌──────┬───┬───┬───┬───┬───┬───┐ ┌───┬───┬───┬───┬───┬───┬──────┐
│      │T1 │ 1 │ 2 │ 3 │ 4 │ 5 │ │ 6 │ 7 │ 8 │ 9 │ 0 │T3 │      │
├──────┼───┼───┼───┼───┼───┼───┤ ├───┼───┼───┼───┼───┼───┼──────┤
│ Tab  │T2 │ x │ v │ l │ c │ w │ │ k │ h │ g │ f │ q │ ß │ Ret  │
├──────┼───┼───┼───┼───┼───┼───┤ ├───┼───┼───┼───┼───┼───┼──────┤
│ Sh   │   │ u │ i │ a │ e │ o │ │ s │ n │ r │ t │ d │ y │ Sh   │
├──────┼───┼───┼───┼───┼───┼───┤ ├───┼───┼───┼───┼───┼───┼──────┤
│ M3   │   │ ü │ ö │ ä │ p │ z │ │ b │ m │ , │ . │ j │   │ M3   │
└──────┴───┴───┴───┴───┴───┴───┘ └───┴───┴───┴───┴───┴───┴──────┘
┌────┬────┬────┬───────┬───────┐ ┌───────┬───────┬────┬────┬────┐
│ Str/Fen/Alt  │  M4   │ leer  │ │ leer  │  M4   │ Fen/Men/Str  │
└────┴────┴────┴───────┴───────┘ └───────┴───────┴────┴────┴────┘
```

In diesem quick&dirty-Entwurf sind jetzt aber zu viele Tasten, man kommt auf beiden Seiten schlecht an die Modifier dran. Die geringfügige Entlastung durch M4 auf dem Daumen fängt das nur teilweise auf. Das kann nicht wirklich ergonomisch sein…

#### Nora2

Eine Alternative wäre, die Anzahl der Spalten gleich zu lassen, und die überzähligen Spalten vom rechten kleinen Finger in die Mitte zu legen. Im Endeffekt müsste man die Buchstabenbelegung natürlich noch optimieren:

```
┌──────┬───┬───┬───┬───┬───┐         ┌───┬───┬───┬───┬───┬──────┐
│ T1   │ 1 │ 2 │ 3 │ 4 │ 5 │         │ 6 │ 7 │ 8 │ 9 │ 0 │ Bsp  │
├──────┼───┼───┼───┼───┼───┼───┐ ┌───┼───┼───┼───┼───┼───┼──────┤
│ Tab  │ x │ v │ l │ c │ w │T2 │ │T3 │ k │ h │ g │ f │ q │ Ret  │
├──────┼───┼───┼───┼───┼───┼───┤ ├───┼───┼───┼───┼───┼───┼──────┤
│ Sh   │ u │ i │ a │ e │ o │ ß │ │ y │ s │ n │ r │ t │ d │ Sh   │
├──────┼───┼───┼───┼───┼───┼───┘ └───┼───┼───┼───┼───┼───┼──────┤
│ M3   │ ü │ ö │ ä │ p │ z │         │ b │ m │ , │ . │ j │ M3   │
└──────┴───┴───┴───┴───┴───┘         └───┴───┴───┴───┴───┴──────┘
┌────┬────┬────┬──────┬────────┐ ┌────────┬──────┬────┬────┬────┐
│ Str/Fen/Alt  │  M4  │ leer   │ │ leer   │  M4  │ Fen/Men/Str  │
└────┴────┴────┴──────┴────────┘ └────────┴──────┴────┴────┴────┘
```

Hier passt zumindest die Anzahl der Tasten, und die Tastatur ist symmetrisch.
Außerdem wird ein bisschen Last von den kleinen Fingern auf die Zeigefinger gelegt.
Nach Jakobs Erfahrungen könnten die Tasten in der Mitte unangenehm zu erreichen sein, 
belegt man sie jedoch mit den selteneren Buchstaben, so könnte dies akzeptabel sein.

#### Karl

Am 12.9.2010 wurde von Karl Köckemann [folgende Tastatur](http://www.abload.de/img/20100305-neohardwareenopkn.png) vorgeschlagen:

```
    ┌───┬───┬───┬───┬───┬───┐             ┌───┬───┬───┬───┬───┬───┐
    │   │ 1 │ 2 │ 3 │ 4 │ 5 │             │ 6 │ 7 │ 8 │ 9 │ 0 │ ß │
    ├───┼───┼───┼───┼───┼───┤             ├───┼───┼───┼───┼───┼───┤
    │T3 │ x │ v │ l │ c │ w ├───┐     ┌───┤ h │ g │ f │ q │ d │T2 │
┌───┼───┼───┼───┼───┼───┼───┤Ins│     │Esc├───┼───┼───┼───┼───┼───┼───┐
│Ent│Sh │ u │ i │ a │ e │ o ├───┘     └───┤ s │ n │ r │ t │Spc│Sh │T1 │
└───┼───┼───┼───┼───┼───┼───┤             ├───┼───┼───┼───┼───┼───┼───┘
    │Alt│ ü │ ö │ ä │ p │ z │             │ b │ m │ , │ . │ j │Alt│
    └───┴───┴───┴─┬─┴─┬─┴─┬─┴─┬───┐ ┌───┬─┴─┬─┴─┬─┴─┬─┴───┴───┴───┘
                  │M4 │M3 │Fn │Fen│ │Men│Fn │M3 │M4 │
                  └─┬─┴─┬─┴─┬─┴─┬─┘ └─┬─┴─┬─┴─┬─┴─┬─┘
                    │Ctl│Tab│Del│     │BSp│Cmp│Ctl│
                    └───┴───┴───┘     └───┴───┴───┘
```

Auch hier sind die Buchstaben erstmal so ähnlich wie bei Neo und müssten dann entsprechend der Lage optimiert werden.
Dieser Vorschlag bindet die Daumen mit je 7 Tasten recht stark ein.

Karl hat außerdem schon [einen Prototypen gebaut](http://www.abload.de/gallery.php?key=a56nsLJg).

#### dunkelziffer: KeyHawk

Mein Vorschlag zu einer eigenen NEO-Tastatur sieht folgendermaßen aus:

[KeyHawk](http://img10.imageshack.us/img10/7466/keyhawk.png)
[KeyHawk 2.0](http://imageshack.us/a/img28/5834/l34.png)

Diese Tastatur ähnelt sehr stark dem Design des Truly Ergonomic Keyboard, hat aber zusätzliche Daumentasten. Rechts liegt wie gewohnt die Leertaste. Zusätzlich habe ich Enter und Backspace auf den rechten Daumen gelegt. Links liegen M3, M4 und ein neuer Modifier "Fn/Media".

Ein weiterer Unterschied ist, dass die Navigationsblöcke etwas nach unten und außen gewandert sind, um den Daumentasten Platz zu machen. Außerdem haben sie wieder die gewohnte umgedrehte T-Form, nicht wie beim TEK die liegende Raute. Meines Erachtens ist diese Anordnung sogar ergonomischer (eine der seltenen guten Seiten der Standardtastatur), da der Mittelfinger so in neutraler Position genau zwischen UP und DOWN zu liegen kommt und in beide Richtungen den gleichen Weg hat. Beim TEK liegt er in neutraler Position auf UP und muss einen viel größeren Weg nach unten (auch noch die schwächere Richtung) gehen, um DOWN zu erreichen.

Da die beiden Modifier jetzt Daumen-Tasten sind, gibt es sie nur noch einmal. Dies sollte kein Problem darstellen, da es die Bewegungsfreiheit der anderen Finger der selben Hand kaum einschränkt, wenn man mit dem Daumen eine Taste drückt/gedrückt hält. Im Gegenteil, Ebene 5 und 6 sind nun sogar leichter zu erreichen. Bis jetzt musste man entweder zwei Modifier auf einer Seite drücken (umständlich), oder einen Modifier und den gewünschten Buchstaben (was ja bei Shift möglichst immer vermieden wird). Jetzt kann man wie gewohnt Shift auf der anderen Seite drücken, als den Buchstaben, nur ein sowieso untätiger Daumen muss zusätzlich arbeiten.

Vollständig neu ist der "Fn/Media" Modifier. Er ersetzt alle zwölf Fn-Tasten, die nun in den gewohnten drei 4er-Blöcken auf die rechte Hand verteilt sind. Zusätzlich bietet er Platz für 15 der heutzutage so beliebten Media-Tasten. Als ultimatives Argument für den neuen Modifier habe ich auf den drei verbleibenden Tasten des Hauptblocks die Shortcuts für Cut, Copy & Paste gelegt. So sind diese nun vollkommen unabhängig von der Buchstabenbelegung der Tastatur immer gut erreichbar.
*(Die einzigen Bedenken, die ich bei diesem Modifier habe, sind Tastenkombinationen mit Fn-Tasten, z.B. Alt-F4. Wären diese mit einem solchen Modifier (auch auf BIOS-Ebene!!!) technisch möglich? - Bitte entfernen, falls geklärt.)*

Die Tottasten sind nun über die ganze Tastatur verstreut, aber nicht schlechter zu erreichen als früher. Die beiden Tasten in den Ecken haben sogar einen etwas geringeren Weg für die kleinen Finger, vals bei einer herkömmlichen Tastatur mit Neo.

Die beiden leeren Tasten unter den Tottasten in den Ecken müssen noch für den Hauptblock verwendet werden. So hat man dann 32 Tasten für 26 Buchstaben + äöüß + 2 Satzzeichen. Ich würde ß und q auf diese Randtasten legen, aber das soll ein Optimierer entscheiden. Als Satzzeichen würde ich ,/- und ./: wählen. Der Strichpunkt ist selten genug geworden, um in die 3. Ebene zu wandern, zumal er dort wunderbar den Programmierzeichen Gesellschaft leistet.

Die je zwei Tasten ganz oben im Eck können noch frei belegt werden, sind aber sehr schlecht zu erreichen. Der "Adler-Kopf" steht (auch wenn das nicht sonderlich schmeichelhaft klingt) für Altlasten wie Rollen, Druck, Pause, CapsLock und NumLock zur Verfügung. Außerdem würde ich eine Taste einbauen, mit der man das Tastaturlayout komplett umstellen kann. Man könnte dann als alternative Layouts Zeichensätze wie Kyrillisch, Hebräisch, Südkoreanisch und Japanisch(Katakana) anbieten. Durch die vielen Modifier wäre auf dieser Tastatur vielleich sogar Chinesich/Japanisch(Hanji/Kanji) möglich. Das würde allerdings die Firmware ziemlich aufblähen. Ob dies technisch machbar ist, kann ich nicht entscheiden.

Und zu guter letzt eine Anmerkung zum Namen. Die Form dieses Designs hat schon in dem Moment, in dem sie das erste mal zu Papier gebracht wurde bei mir die Assoziation eines Adlers hervorgerufen. Da der Adler das deutsche "Wappentier" ist und die Tastatur zwar international ist, aber den Fokus auf die deutsch Sprache richtet, stand er für den Namen der Tastatur Pate. Vielleicht sollte man noch einen deutschen Namen wählen, aber mir ist außer der direkten Übersetzung "Tastenadler" noch keiner eingefallen. Und der klingt schon ziemlich umgangssprachlich (was ja nicht notwendigerweise etwas schlechtes ist).

Ich hoffe euch gefällt mein erster Beitrag zum NEO-Projekt,
dunkelziffer

edit: Zu Version 2.0:

Es hat sich einiges verändert. Shift ist auch zur Daumentaste geworden (und hat natürlich den besten Platz bekommen). Es liegen also jetzt alle Modifier auf den Daumen und tauchen somit nur noch einmal auf. Fn/Media ist in die Mitte gewandert. Die Tottasten in den Ecken und die beiden darunter liegenden Buchstaben sind durch den Umzug von Shift eine Taste runter gerutscht. Das hat Platz geschaffen um nun auch Esc und das obere Del in den Hauptblock aufzunehmen. (Insbesondere Esc sollte vim-Nutzer erfreuen.) Dabei tritt das Problem auf, das Ebene 5 und 6 jetzt schlechter zu erreichen sind. Evtl. tauschen M3 und M4 mit Enter und Bsp. die Plätze, obwohl ich Enter und Bsp. links für gewöhnungsbedürftig halte.

Außerdem wurde die Form der Daumentasten so angepasst, das bei den Steuertasten jeweils ein bisschen Platz frei wurde. Dies schafft links Raum für die von Fn/Media aus der Mitte vertriebene Tottaste (zugegeben nicht sonderlich gut positionert).

Auf der rechten Seite habe ich eine Notfall-Maus angedacht, falls mal garnichts anderes zur Verfügung steht. Einen kleinen "Control-Stick", wie es ihn früher in Laptop-Tastaturen gab, und ein Scroll-Rad mit Druck- und Kippfunktion. Der Druck aufs Scrollrad funktioniert wie gewohnt, die Kippfunktion kann die beiden Maustasten ansteuern. Natürlich ist dies nur als Behelf gedacht, an Drag- and Drop möchte ich garnicht denken. Aber ich kann mir durchaus vorstellen, beim Lesen längerer Internetseiten (also wenn man nicht gerade häufig klicken muss) das Scrollrad der Tastatur zu verwenden. Und mit einem vernünftigen Control-Stick, vielleicht in der Form eines analogen Schiebepads, kann ich mir durchaus vorstellen, das man anfängt zu überlegen, für kürzere Mausbenutzungen die Hand nicht mehr von der Tastatur zu nehmen.

Insbesondere scheint es mit dieser Tastenanordnung trotz der vielen Modifier möglich, links und rechts eine Reihe Tasten wegzulassen (grüne Linie).

## Anfragen/Herstellerüberlegungen

Jakob H. regte am 9.9.2010 auf der ML eine Zusammenarbeit mit TypeMatrix an.
Herr Dolleschel, der für die Firma GAMPro IT-Consulting & Service die Interessen von TypeMatrix in Deutschland vertritt, habe ihm zugesichert, dass von TypeMatrix aus ein großes Interesse an einer Zusammenarbeit mit der Neo-Community besteht.
Möglichkeiten bestünden wohl im Bedrucken einer Standard-TypeMatrix mit der Neo-Tastatur, aber auch in einer Zusammenarbeit zu einer kompletten Neuentwicklung.
Für den Absatz müsste sich ein „Vertreter“ für den deutschen Markt finden, in Frankreich macht dies wohl die dortige Dvorak-Community.
Als Mindestmenge wurden 200 Stück neuer Skins oder Tastaturen genannt.

Analog wurde überlegt, ob nicht lieber eine Kooperation mit dem Truly Ergonomic Keyboard angestrebt werden sollte, da dies schon in der Standardform viel Übereinstimmung mit den Neo-Interessen zeigt. Dies ist nicht wahrscheinlich, da die Macher des Truly Ergonomic Keyboard eher ablehnend auf eine Anfrage antworteten.

Die Kinesis Advantage (ziemlich teuer) könnte als Vorbild für ein selbstentwickeltes Modell herhalten.

2006 ist auch schon einmal eine Kooperation mit Cherry geplant worden, die 2008 ergebnislos versandet ist. Die Details lassen sich [hier](NeoTastaturen.md#neo-tastatur-von-cherry) nachlesen.
