# LaTeX und Neo
Der typische (La)TeX-Nutzer profitiert in vielfacher Weise vom Neo-Tastaturlayout: Neben den ergonomischen Anordnung der Buchstaben sind beispielsweise auch die häufiger benötigten Sonderzeichen wie \{}[]|$ viel besser erreichbar.

Um in einem LaTeX-Dokument (in der Quelldatei) jedoch auch die vielen typografischen Sonderzeichen der Neo-Tastaturbelegung (z. B. deutsche/französische/englische Anführungszeichen, Gedankenstrich, Auslassungspunkte, griechische Buchstaben, mathematische Symbole, …) direkt eingeben zu können, so dass sie anschließend auch korrekt im Ausgabedokument dargestellt werden, muss man jedoch ein paar Dinge wissen und beachten.

Alle hier vorgestellten Pakete und Programme zielen darauf ab, darüber hinaus auch die Unicode-Zeichen auf der Neo-Tastatur direkt in LaTeX eingeben zu können.

## LuaTeX / XeTeX
LuaTeX und XeTeX sind moderne TeX-Engines, die neben Unicode auch moderne Formate für Schriften (sprich OpenType-Fonts) samt Stylistic Sets und diversesten Ligaturen unterstützen. Ferner ist man dadurch nicht mehr auf 256 Zeichen pro Schrift limitiert, was z.B. 
automatische Silbentrennung und Ligaturen in Legacy-TeX sehr behindert. In LuaLaTeX und XeLaTeX kann man alle Symbole, die in der ausgewählten Schrift vorhanden sind, ohne weiteres einfach benutzen.

LuaTeX und XeTeX sind größtenteils mit pdfTeX kompatibel, jedoch gibt es Ausnahmen:
Einige Features des __microtype__-Pakets sind (vor allem bei XeTeX) nicht verfügbar; die allermeisten Pakete (z.B. Koma-Script) funktionieren jedoch ohne Probleme. Lua- und XeTeX stellen die derzeit beste Variante dar, um Unicode-Zeichen in LaTeX nutzen zu können.
Es ist noch anzumerken, dass LuaTeX im Gegensatz zu XeTeX Scripting in Lua ermöglicht, was z.B. von manchen
Funktionen des __tikz__-Pakets verwendet wird. LuaTeX gilt als die derzeit fortschrittlichste TeX-Engine und  Nachfolger der pdfTeX-Engine.

### Mathematik mit unicode-math
Mit LuaTex und XeTeX können Unicode-Zeichen auch im Mathematik-Modus gesetzt werden. Das wird erreicht durch Will Robertsons Paket __unicode-math__, das inzwischen [auf CTAN](https://ctan.org/pkg/unicode-math) verfügbar ist. Die stets aktuelle Entwicklungsversion von unicode-math befindet auf [GitHub](https://github.com/wspr/unicode-math).

Der Author Will Robertson führt die Fortentwicklung des Paketes unicode-math momentan regelmäßig weiter und beschäftigt sich gleichzeitig im Rahmen des [LaTeX3-Projektes](http://www.latex-project.org/latex3.html), um eine ordentliche Grundlage für eine bessere Implementierung von unicode-math zu erarbeiten.

Noch mehr Funktionen bietet das auf unicode-math aufbauende Paket __alttex__. Es richtet sich an besonders experimentierfreudigen Neo-Nutzern mit viel TeX-Erfahrung und bietet etwa die Möglichkeit, Matrizen direkt
in Unicode einzugeben und weitere Features. Es wurde seit 2010 nicht mehr verändert und ist laut Readme nur mit XeTeX voll kompatibel. Das sehr experimentelle Paket ist auf [github](https://github.com/alt/alttex) verfügbar.

### Mathematik mit uniinput
Alternativ kann man auch viele mathematische Zeichen mit dem __uniinput__-Paket, das [hier](https://git.neo-layout.org/neo/latex-unicode-extras/src/branch/master/Standard-LaTeX) zu finden ist, eingeben. Im Gegensatz zu
unicode-math benutzt uniinput weiter die alten Ausgaberoutinen, und die Ergebnisse sehen exakt so aus wie bei
klassischem TeX. Bei unicode-math hingegen trifft man ab und zu auf Bugs im neuen Renderer und kann nur die neuen OpenType-Schriften mit Mathematik-Support benutzen – von denen es noch relativ wenige gibt.
Jedoch unterstützt uniinput wesentlich weniger Zeichen als unicode-math.

## Mathematik mit Legacy-pdfLaTeX
Die hier angebotenen Alternativen haben den Vorteil, mit dem veralteten pdfLaTeX  benutzt werden zu können.

### ucs + utf8x
Mit dem Paket __ucs__ (in texlive und mactex enthalten) können durch folgende Einträge in der Präambel die Zeichen der Neo-Tastatur direkt eingegeben und übersetzt werden:  
```
\usepackage[mathletters]{ucs}  
\usepackage[utf8x]{inputenc}  
```

### uniinput
Das [uniinput-Paket](https://git.neo-layout.org/neo/latex-unicode-extras/src/branch/master/Standard-LaTeX/) ist auch mit Legacy-pdfTeX kompatibel.
Es bietet weniger Features als ucs.

### Compose-Erweiterung für Lyx
Einen anderen Weg geht die Compose-Erweiterung [lyx.module](https://git.neo-layout.org/neo/latex-unicode-extras/raw/branch/master/lyx/lyx.module) (die Installationsanleitung für Lyx befindet sich in der Datei). Hier werden die von der Neo-Tastatur gesendeten Unicode-Zeichen (via [Compose](../Benutzerhandbuch/Tote-Tasten-und-Compose.md#erzeugbare-zeichen-mit-compose)) auf die entsprechenden LaTeX-Konstrukte abgebildet, also auch im ASCII-Format gespeichert (… → `\ldots`). Die Unicodezeichen werden also nur für die Eingabe verwendet.


## Typographische Möglichkeiten unter macOS

Unter macOS gibt es weitergehende Möglichkeiten unter dem Gesamtkonzept __Apple Advanced Technology__ (AAT), die mit XeLaTeX genutzt werden können.

### Fraction Slash

In XeLaTeX kann man mit fontspec und einer AAT-Schriftart (leider keine OpenType)
den fraction slash verwenden, um auf Schriftebene Brüche zu schreiben.
Dabei wird dann die Eingabe ```13579⁄24680``` als `¹³⁵⁷⁹⁄₂₄₆₈₀` ausgegeben.
Beim verwendeten Schrägstrich handelt es sich um den Fraction Slash, der auf ++mod4+Num-slash++ liegt.

Dafür ist in der Präambel folgende Option einzustellen:
```
\addfontfeature{Fractions=Diagonal})
```

## Links

 * [trennmuster.org](https://groups.google.com/g/trennmuster-opensource) Erstellung freier Trennmuster für die deutsche Sprache.
 * [de.comp.text.tex](https://groups.google.com/g/de.comp.text.tex) ist eine deutschsprachige Newsgroup, die sich mit LaTeX beschäftigt.
