# Striche

Es gibt sehr viele verschiedene Striche. Diese Seite soll aufzeigen,

 * welche Striche es gibt und wozu sie eingesetzt werden können und sollen (wobei es einen Teil dieser Infos auch unter [Typografie mit Neo](Typografie-mit-Neo.md) gibt),
 * wie diese mit Neo erreicht werden können und sollen,
 * und welche Striche nicht mit Neo erreichbar sind.

## Mögliche Striche

Im Unicode ist eine Vielzahl verschiedener Striche definiert.

  * *hyphen-minus* (U+002D) Bindestrichminus, Viertelgeviertstrich
    * Dieses Zeichen wird von herkömmlichen (deutschen und internationalen) Tastaturen auf der Minus-/Bindestrichtaste (des Hauptfeldes) erzeugt.
    * Ist das Standard-Minus- und Bindestrichzeichen der EDV: wird in Formeln, Tastenkürzeln (z.B. Strg+- = Verkleinern), und E-Mail-/Webadressen verwendet. 
    * Als Bindestrich typografisch ok, das eigentliche Zeichen wäre aber der (genauso aussehende) *hyphen*.
    * Als Bindestrichminus ist es typografisch eigentlich nicht korrekt, wird aber trotzdem beim Programmieren, in Tabellenkalkulationen in Taschenrechnern etc. dem echte Minus vorgezogen bzw. als Eingabe erwartet.
    * Als Gedankenstrich sollte im Deutschen und Französischen der *en-dash* (Halbgeviertstrich), im Englischen und Spanischen der *em-dash* (Geviertstrich) verwendet werden.
  * *hyphen* (U+2010) der „richtige“ Bindestrich
    * Der Bindestrich unterscheidet sich im Aussehen nicht vom *hyphen-minus*, ist also typographisch nicht „richtiger“ als das hyphen-minus, denn beide, ‐ und -, sind Viertelgeviertstriche. Die Unterscheidung kommt erst durch die Kodierung durch den Computer zu Stande und ist somit zum Teil künstlich. In den wenigen Fällen, in denen der echte Bindestrich „richtiger“ wäre, ist aber auch das Bindestrichminus vertretbar.
    * Der echte Bindestrich kann nur dann sinnvoll verwendet werden, wenn Wörter zusammengesetzt werden (z.B. Bundestags‐Kantine, manisch‐depressives Verhalten). Oft sollte stattdessen die Zusammenschreibung bevorzugt werden (Gartentor statt Garten-Tor), es sei denn, es ergibt sich eine Doppelbedeutung oder das entstandene Wort ist unverständlich lang. So ist „Hals‐Nasen‐Ohren‐Arzt“ sinnvoller als „Halsnasenohrenarzt“, wohingegen man niemals „Frauen‐Arzt“ schreiben würde.
    * Vorsichtig zu verwenden: Da er genauso aussieht, wie das *hyphen-minus*, entstehen leicht Fehler mit Programmen, die nur das *hyphen-minus* erwarten und nicht den echten *hyphen*.
  * *non-breaking-hyphen* (U+2011) Geschützter Bindestrich, bei dem *keine* Trennstelle eingefügt wird
    * Zu Empfehlen bei Zusammensetzungen, die nicht getrennt werden sollten: A‑Z, T‑Punkt, E‑Mail, H‑Milch, U‑Bahn, Make‑up u. ä.
  * *hyphen-bullet* (U+2043) Aufzählungsstrich
  * *minus sign* (U+2212) echtes Minus, korrektes Minus
    * das typographisch korrekte Minuszeichen, stets so breit wie Plus-Zeichen der jeweiligen Schrift, also meistens ein bisschen breiter als das normale Bindestrichminus
  * *soft hyphen* (U+00AD) weicher Trennstrich
    * zeigt mögliche Worttrennungen an, dies ermöglicht etwa Silbentrennung bei HTML-Seiten
    * erscheint jedoch nur, wenn ein Wort am Zeilenende getrennt wird
    * Dieses Zeichen wurde in älteren Zeichsätzen (vor Unicode) widersprüchlich aufgefasst, so dass es eventuell zu Probleme mit älteren Programmen kommen kann: [Soft hyphen — a hard problem?](http://www.cs.tut.fi/~jkorpela/shy.html) 
  * *figure dash* (U+2012) ungefähr so breit wie eine Ziffer
  * *en-dash* (U+2013) Gedankenstrich, Halbgeviertstrich (so breit wie das kleine n)
    * Kann auch als Aufzählungsstrich verwendet werden
  * *em-dash* (U+2014) Langer Gedankenstrich, Geviertstrich (so breit wie das große M)
  * *horizontal bar* (U+2015): Zitatstrich oder Horizontalstrich
    * Wird in Theatertexten und Romanen  für den Beginn der wörtlichen Rede verwendet
    * Dies kennzeichnet den Wechsel der Sprecher besser als herkömmliche Anführungszeichen
    * Wird fast nur in englischen und französischen Texten eingesetzt
    * Optisch der längste in Unicode codierte Strich

Darüber hinaus wird vom Betriebssystem noch ein weiterer Strich unterschieden:

  * *KP_Minus* (U+002D) Ziffernblock-Bindestrichminus, Keypad-Minus
    * Dieses Zeichen ist kein kein eigenes Zeichen, sondern identisch zum normalen *hyphen-minus*; insbesondere hat es den selben Unicode-Codepoint.
    * Hier wird nur der Anwendung im Moment des Tastendrucks signalisiert bzw. vorgespiegelt, dass eine Taste auf dem Keypad gedrückt wurde.
    * Es gibt Anwendungsprogramme (Textverarbeitung, Tabellenkalkulation, …) die dies tatsächlich abfragen.

### Erreichbarkeit der Striche

Ein Sammelbecken für Striche ist die **Strichtaste**.

  * Ebene 1: Bindestrichminus
  * Ebene 2: em-dash
  * Ebene 3: unbelegt
  * Ebene 4: KP_Minus (also das Bindestrichminus wie auf Ebene 1)
  * Ebene 5: Geschützter Bindestrich
  * Ebene 6: Weicher Trennstrich
    * Geschützter Bindestrich und Weicher Trennstrich liegen mit Absicht auf den schlecht erreichbaren Ebenen 5 und 6, da hier eine versehentliche Eingabe zu Problemen führen kann.

Das Minuszeichen des Ziffernblocks (sowohl Hardware, als auch Ebene 4) gibt ein KP_Minus aus. Das Bindestrichminus ist also mehrfach vorhanden, zusätzlich noch auf der Programmierebene über Mod3+t.

Der geschützte Bindestrich wurde bewusst auf die selbe Ebene wie das geschützte Leerzeichen gelegt.

Der *en-dash* ist über Shift+Komma erreichbar und dient dort sowohl als Gedanken- als auch als Aufzählungsstrich.

Der echte Hyphen ist nur über Compose/Deadkeys erreichbar, um Verwirrungen durch die versehentliche Eingabe zu vermeiden: Entweder \<Schrägstrich\> \<space\> oder <Mod3+Akut> (\<space\>/<Shift+space>/<Mod3+space>)

Das korrekte Minuszeichen kann nur auf der 3. Ebene der Minustaste des Ziffernblocks erreicht werden, da es einen ausgesprochen kleinen Anwendungsbereich (verschriftlichte Rechnungen etc.) hat. Wer also keine mathematischen Rechnungen niederschreibt, benötigt ihn nicht; wer dies häufig macht, benutzt meist LaTeX und nimmt stattdessen das einfache Bindestrichminus.

### Fehlende Striche

Von den möglichen Strichen sind drei mit Neo nicht erreichbar: *hyphen bullet*, *figure dash* und der *Zitatstrich*. 
Für keinen der drei gibt es bislang wesentliche Gründe, sie aufzunehmen:

  * *hyphen bullet* und *figure dash*
    * nur sehr selten verwendet
    * optisch fast identisch zu Bindestrichminus oder Gedankenstrich
  * *Zitatstrich*
    * P: Passt von der Logik her ganz hervorragend auf die dritte Ebene der Strichtaste, die eh noch leer ist. 
    * K: optisch sehr ähnlich zu em-Dash
    * K: sehr selten verwendet
 